<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Admin_Ajax {

    public function __construct() {
        add_action('wp_ajax_wip_update_options', [$this, 'update_options']);
        add_action('wp_ajax_wip_send_test_sms', [$this, 'send_test_sms']);
        add_action('wp_ajax_wip_send_invoice', [$this, 'send_invoice']);
        add_action('wp_ajax_wip_send_invoice_sms', [$this, 'send_invoice_sms']);
    }

    public function update_options() {
        check_ajax_referer('wip_nonce', 'wipNonce', true);

        parse_str($_POST['formData'], $form_data);
        $update = (new WIP_Options_Manager())->update_options($form_data);

        if ($update) {
            $this->make_response(['result' => true]);
        }

        wp_send_json_error();
    }

    public function send_test_sms() {
        check_ajax_referer('wip_nonce', 'wipNonce', true);

        $phone = $_POST['phone'];
        $options = new WIP_Options_Manager();
        $service = $options->get_option('sms-service');
        $class = 'WIP_' . ucfirst($service);
        $result = (new $class(1, $phone, __('Test message from ', 'wip') . get_bloginfo('name')))->send();
        wp_send_json(['result' => $result]);
    }

    public function send_invoice() {
        check_ajax_referer('wip_nonce', 'wipNonce', true);

        $order_id = $_POST['orderID'];
        if (!intval($order_id)) {
            wp_send_json_error();
        }

        (new WIP_Notifications())->send_email($order_id);
        $this->make_response(['result' => true]);
    }

    public function send_invoice_sms() {
        check_ajax_referer('wip_nonce', 'wipNonce', true);

        $order_id = $_POST['orderID'];
        if (!intval($order_id)) {
            wp_send_json_error();
        }

        (new WIP_Notifications())->send_sms($order_id);
        $this->make_response(['result' => true]);
    }

    private function make_response($data) {
        if (is_array($data)) {
            wp_send_json($data);
        } else {
            echo $data;
        }

        exit();
    }
}