<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Cart_Total {

    protected $options;
    protected $labels;
    protected $components;

    public function __construct() {
        $this->options = new WIP_Options_Manager();
        $this->labels = new WIP_Labels_Manager();
        $this->components = $this->options->get_option('components');
    }

    public function render_html() {
        if (!isset($this->components['total-table']['pre-invoice'])) {
            return null;
        }

        $coupons = WC()->cart->get_coupons();
        $rates = WC()->session->get('shipping_for_package_0')['rates'];

        ob_start();
        ?>
        <table class="cart-total-table table-responsive table-bordered">
            <tbody>
            <?php if (isset($this->components['total-total']['pre-invoice'])): ?>
                <tr class="cart-subtotal">
                    <th><?php echo esc_html($this->labels->get_label('total-amount')); ?></th>
                    <td><?php wc_cart_totals_subtotal_html(); ?></td>
                </tr>
            <?php endif; ?>
            <?php if (isset($this->components['total-discount']['pre-invoice']) && sizeof($coupons)): ?>
                <tr class="cart-discount">
                    <th><?php echo esc_html($this->labels->get_label('discount-amount')); ?></th>
                    <td>
                        <?php foreach (WC()->cart->get_coupons() as $code => $coupon) : ?>
                            <div><?php wc_cart_totals_coupon_label($coupon); ?></div>
                            <div><?php wc_cart_totals_coupon_html($coupon); ?></div>
                        <?php endforeach; ?>
                    </td>
                </tr>
            <?php endif; ?>
            <?php if (isset($this->components['total-shipping']['pre-invoice']) && is_array($rates) && count($rates)): ?>
                <tr class="total-shipping">
                    <th><?php echo esc_html($this->labels->get_label('shipping-amount')); ?></th>
                    <td>
                        <?php
                        foreach ($rates as $method_id => $rate) {
                            if (WC()->session->get('chosen_shipping_methods')[0] == $method_id) {
                                $rate_label = $rate->label;
                                $rate_cost_excl_tax = floatval($rate->cost);
                                $rate_taxes = 0;
                                foreach ($rate->taxes as $rate_tax) {
                                    $rate_taxes += floatval($rate_tax);
                                }
                                $rate_cost_incl_tax = $rate_cost_excl_tax + $rate_taxes;
                                echo '<p class="shipping-total"><span class="label">' . $rate_label . ': </span><span class="totals">' . WC()->cart->get_cart_shipping_total() . '</span></p>';
                                break;
                            }
                        }
                        ?>
                    </td>
                </tr>
            <?php endif; ?>
            <?php if (isset($this->components['total-fee']['pre-invoice'])): ?>
                <?php foreach (WC()->cart->get_fees() as $fee) : ?>
                    <tr class="fee">
                        <th><?php echo esc_html($fee->name); ?></th>
                        <td data-title="<?php echo esc_attr($fee->name); ?>"><?php wc_cart_totals_fee_html($fee); ?></td>
                    </tr>
                <?php endforeach; ?>
            <?php endif; ?>
            <?php if (isset($this->components['total-tax']['pre-invoice'])): ?>
                <?php
                if (wc_tax_enabled() && !WC()->cart->display_prices_including_tax()) {
                    $taxable_address = WC()->customer->get_taxable_address();
                    $estimated_text = '';

                    if (WC()->customer->is_customer_outside_base() && !WC()->customer->has_calculated_shipping()) {
                        $estimated_text = sprintf(' <small>' . esc_html__('(estimated for %s)', 'woocommerce') . '</small>', WC()->countries->estimated_for_prefix($taxable_address[0]) . WC()->countries->countries[$taxable_address[0]]);
                    }

                    if ('itemized' === get_option('woocommerce_tax_total_display')) {
                        foreach (WC()->cart->get_tax_totals() as $code => $tax) {
                            ?>
                            <tr class="tax-rate tax-rate-<?php echo esc_attr(sanitize_title($code)); ?>">
                                <th><?php echo esc_html($tax->label) . $estimated_text; ?></th>
                                <td><?php echo wp_kses_post($tax->formatted_amount); ?></td>
                            </tr>
                            <?php
                        }
                    } else {
                        ?>
                        <tr class="tax-total">
                            <th><?php echo esc_html(WC()->countries->tax_or_vat()) . $estimated_text; ?></th>
                            <td><?php wc_cart_totals_taxes_total_html(); ?></td>
                        </tr>
                        <?php
                    }
                }
                ?>
            <?php endif; ?>
            <?php if (isset($this->components['total-final']['pre-invoice'])): ?>
                <tr class="order-total">
                    <th><?php echo esc_html($this->labels->get_label('final-amount')); ?></th>
                    <td><?php wc_cart_totals_order_total_html(); ?></td>
                </tr>
            <?php endif; ?>
            <?php if ($this->options->get_option('to-word')): ?>
                <tr>
                    <td class="to-word" colspan="2"><?php echo WIP_Helper::to_word(WC()->cart->get_total(null)) . ' ' . get_woocommerce_currency_symbol() ?></td>
                </tr>
            <?php endif; ?>
            </tbody>
        </table>
        <?php
        return ob_get_clean();
    }
}