<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Checkout_Field {

    private $options;
    private $labels;

    public function __construct() {
        $this->options = new WIP_Options_Manager();
        $this->labels = new WIP_Labels_Manager();

        if ($this->options->get_option('national-id')) {
            add_filter('woocommerce_checkout_fields', [$this, 'add_national_id']);
            add_action('woocommerce_admin_billing_fields', [$this, 'show_national_id'], 10, 1);
            if (!$this->options->get_option('no-validate-national-id')) {
                add_action('woocommerce_checkout_process', [$this, 'checkout_field_process']);
            }
        }

        if ($this->options->get_option('receiving-invoice-selection')) {
            add_filter('woocommerce_checkout_fields', [$this, 'add_receiving_invoice']);
            add_action('woocommerce_admin_billing_fields', [$this, 'show_receiving_invoice'], 10, 1);
        }
    }

    public function add_national_id($fields) {
        $orders = WIP_Helper::customer_orders(get_current_user_id());
        $last_order = $orders[0] ?? null;

        $fields['billing']['billing_national_id'] = array(
            'label' => __('National ID/Economical number', 'wip'),
            'placeholder' => __('National ID/Economical number', 'wip'),
            'required' => true,
            'class' => array('form-row-wide'),
            'clear' => true,
            'default' => $last_order ? get_post_meta($last_order->ID, '_billing_national_id', true) : '',
        );

        return $fields;
    }

    public function add_receiving_invoice($fields) {
        $fields['billing']['billing_receiving_invoice'] = array(
            'type' => 'checkbox',
            'label' => __('Receiving invoice', 'wip'),
            'default' => '1',
        );

        return $fields;
    }

    public function checkout_field_process() {
        $national_id = $_POST['billing_national_id'];
        if (!empty($national_id) && !$this->check_national_code($national_id)) {
            wc_add_notice($this->labels->get_label('national-is-wrong'), 'error');
        }
    }

    private function check_national_code($code) {
        if ($code == 0) {
            return false;
        }

        $search = ['٠', '١', '٢', '٣', '٤', '۴', '٥', '۵', '٦', '۶', '٧', '٨', '٩'];
        $replace = ['0', '1', '2', '3', '4', '4', '5', '5', '6', '6', '7', '8', '9'];
        $code = str_replace($search, $replace, $code);

        if (!preg_match('/^[0-9]{10}$/', $code)) {
            return false;
        }
        for ($i = 0; $i < 10; $i++) {
            if (preg_match('/^' . $i . '{10}$/', $code)) {
                return false;
            }
        }
        for ($i = 0, $sum = 0; $i < 9; $i++) {
            $sum += ((10 - $i) * intval(substr($code, $i, 1)));
        }
        $ret = $sum % 11;
        $parity = intval(substr($code, 9, 1));
        if (($ret < 2 && $ret == $parity) || ($ret >= 2 && $ret == 11 - $parity)) {
            return true;
        }
        return false;
    }

    public function show_national_id($fields) {
        //global $post;

        $fields['national_id'] = array(
            'label' => $this->labels->get_label('national-id'),
            'show' => true,
            'wrapper_class' => 'form-field-wide',
            'style' => '',
        );

        return $fields;
    }

    public function show_receiving_invoice($fields) {
        //global $post;

        $fields['receiving_invoice'] = array(
            'type' => 'select',
            'label' => __('Receiving invoice', 'wip'),
            'class' => '',
            'wrapper_class' => 'form-field-wide',
            'show' => true,
            'options' => [
                '1' => __('Yes', 'wip'),
                '' => __('No', 'wip'),
            ],
        );

        return $fields;
    }
}