<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Invoice_Access {

    private $order_id;
    private $order;
    private $user_id;
    private $type;
    private $options;

    public function __construct($order_id, $user_id, $type = 'invoice') {
        $this->order_id = $order_id;
        $this->order = wc_get_order($order_id);
        $this->user_id = $user_id;
        $this->type = $type;
        $this->options = new WIP_Options_Manager();
    }

    private function get_user_roles() {
        $user_meta = get_userdata($this->user_id);

        return $user_meta && is_array($user_meta->roles) ? $user_meta->roles : [];
    }

    private function check_user_role() {
        $roles = $this->options->get_option('user-roles');
        $roles = is_array($roles) ? $roles : [];

        return (bool)count(array_intersect($roles, $this->get_user_roles()));
    }

    private function check_order_status() {
        $statuses = $this->options->get_option('order-statutes');
        $statuses = is_array($statuses) ? $statuses : [];
        $order_status = $this->order->get_status();

        return in_array('wc-' . $order_status, $statuses);
    }

    private function check_user_id() {
        return $this->order->get_user_id() == $this->user_id;
    }

    private function check_account_button() {
        return $this->options->get_option('account-btn');
    }

    private function check_vendor() {
        if (isset($_GET['is-vendor'])) {
            $disable = get_post_meta($this->order_id, '_wip_disable_vendor', true);

            return !$disable && (dokan_get_seller_id_by_order($this->order_id) == $this->user_id);
        }

        return true;
    }

    public function check_permission() {
        if (in_array('administrator', $this->get_user_roles())) {
            return true;
        }

        if ($this->check_user_role()) {
            return true;
        }

        if (!WIP_Helper::check_receiving($this->order_id)) {
            return false;
        }

        if ($this->check_user_id()) {
            return $this->check_order_status() && $this->check_account_button() && $this->type == 'invoice';
        }

        return $this->check_user_role() && $this->check_vendor();
    }
}