<?php
defined( 'ABSPATH' ) || exit( __( 'No Access!', 'wip' ) );

class WIP_Jalali_Date {

	public static function tr_num( $str, $mod = 'en', $mf = '٫' ) {
		$num_a = array( '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '.' );
		$key_a = array( '۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹', $mf );

		return ( $mod == 'fa' ) ? str_replace( $num_a, $key_a, $str ) : str_replace( $key_a, $num_a, $str );
	}

	public static function gregorian_to_jalali( $gy, $gm, $gd, $mod = '' ) {
		list( $gy, $gm, $gd ) = explode( '_', self::tr_num( $gy . '_' . $gm . '_' . $gd ) );/* <= Extra :اين سطر ، جزء تابع اصلي نيست */
		$g_d_m = array( 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 );
		if ( $gy > 1600 ) {
			$jy = 979;
			$gy -= 1600;
		} else {
			$jy = 0;
			$gy -= 621;
		}
		$gy2  = ( $gm > 2 ) ? ( $gy + 1 ) : $gy;
		$days = ( 365 * $gy ) + ( (int) ( ( $gy2 + 3 ) / 4 ) ) - ( (int) ( ( $gy2 + 99 ) / 100 ) ) + ( (int) ( ( $gy2 + 399 ) / 400 ) ) - 80 + $gd + $g_d_m[ $gm - 1 ];
		$jy   += 33 * ( (int) ( $days / 12053 ) );
		$days %= 12053;
		$jy   += 4 * ( (int) ( $days / 1461 ) );
		$days %= 1461;
		$jy   += (int) ( ( $days - 1 ) / 365 );
		if ( $days > 365 ) {
			$days = ( $days - 1 ) % 365;
		}
		if ( $days < 186 ) {
			$jm = 1 + (int) ( $days / 31 );
			$jd = 1 + ( $days % 31 );
		} else {
			$jm = 7 + (int) ( ( $days - 186 ) / 30 );
			$jd = 1 + ( ( $days - 186 ) % 30 );
		}

		return ( $mod === '' ) ? array( $jy, $jm, $jd ) : $jy . $mod . $jm . $mod . $jd;
	}

	public static function jalali_to_gregorian( $jy, $jm, $jd, $mod = '' ) {
		list( $jy, $jm, $jd ) = explode( '_', self::tr_num( $jy . '_' . $jm . '_' . $jd ) );/* <= Extra :اين سطر ، جزء تابع اصلي نيست */
		if ( $jy > 979 ) {
			$gy = 1600;
			$jy -= 979;
		} else {
			$gy = 621;
		}
		$days = ( 365 * $jy ) + ( ( (int) ( $jy / 33 ) ) * 8 ) + ( (int) ( ( ( $jy % 33 ) + 3 ) / 4 ) ) + 78 + $jd + ( ( $jm < 7 ) ? ( $jm - 1 ) * 31 : ( ( $jm - 7 ) * 30 ) + 186 );
		$gy   += 400 * ( (int) ( $days / 146097 ) );
		$days %= 146097;
		if ( $days > 36524 ) {
			$gy   += 100 * ( (int) ( -- $days / 36524 ) );
			$days %= 36524;
			if ( $days >= 365 ) {
				$days ++;
			}
		}
		$gy   += 4 * ( (int) ( ( $days ) / 1461 ) );
		$days %= 1461;
		$gy   += (int) ( ( $days - 1 ) / 365 );
		if ( $days > 365 ) {
			$days = ( $days - 1 ) % 365;
		}
		$gd = $days + 1;
		foreach (
			array(
				0,
				31,
				( ( ( $gy % 4 == 0 ) and ( $gy % 100 != 0 ) ) or ( $gy % 400 == 0 ) ) ? 29 : 28,
				31,
				30,
				31,
				30,
				31,
				31,
				30,
				31,
				30,
				31,
			) as $gm => $v
		) {
			if ( $gd <= $v ) {
				break;
			}
			$gd -= $v;
		}

		return ( $mod === '' ) ? array( $gy, $gm, $gd ) : $gy . $mod . $gm . $mod . $gd;
	}
}