<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Options_Manager {

    private $option;
    private $options;

    public function __construct() {
        $this->option = 'wip_options';
        $this->options = get_option($this->option);
    }

    public function get_option($key) {
        if ($this->options && is_array($this->options) && isset($this->options[$key])) {
            return $this->options[$key];
        }

        return null;
    }

    public function update_options(array $data) {
        foreach ($this->sanitize_rules() as $name => $function) {
            if (!is_array($data[$name])) {
                $data[$name] = $function($data[$name]);
                if (empty($data[$name])) {
                    unset($data[$name]);
                }
            } else {
                foreach ($data[$name] as $key => $value) {
                    $data[$name][$key] = $function($data[$name][$key]);
                    if (empty($data[$name][$key])) {
                        unset($data[$name][$key]);
                    }
                }
            }
        }

        return update_option($this->option, $data);
    }

    private function sanitize_rules() {
        return [
            'pre-invoice-page' => 'intval',
            'shop-logo' => 'intval',
            'shop-title' => 'sanitize_text_field',
            'shop-economical-num' => 'sanitize_text_field',
            'shop-reg-num' => 'sanitize_text_field',
            'shop-url' => 'sanitize_text_field',
            'shop-postcode' => 'sanitize_text_field',
            'shop-email' => 'sanitize_text_field',
            'shop-phone' => 'sanitize_text_field',
            'shop-addr' => 'sanitize_textarea_field',
            'user-meta' => 'sanitize_text_field',
            'order-meta' => 'sanitize_text_field',
            'product-meta' => 'sanitize_text_field',
            'invoice-font-size' => 'intval',
            'invoice-margin' => 'intval',
            'custom-css' => 'sanitize_textarea_field',
            'hidden-line-items' => 'sanitize_text_field',
            'prefix' => 'sanitize_text_field',
            'suffix' => 'sanitize_text_field',
            'start-num' => 'intval',
            'shop-signature' => 'intval',
            'watermark' => 'intval',
            'watermark-pending' => 'intval',
            'watermark-processing' => 'intval',
            'watermark-on-hold' => 'intval',
            'watermark-completed' => 'intval',
            'watermark-cancelled' => 'intval',
            'watermark-refunded' => 'intval',
            'watermark-failed' => 'intval',
            'watermark-opacity' => 'sanitize_text_field',
            'post-label-font-size' => 'intval',
            'post-label-margin' => 'intval',
            'orders-font-size' => 'intval',
            'orders-margin' => 'intval',
            'email-from' => 'sanitize_text_field',
            'from-name' => 'sanitize_text_field',
            'recipients-email' => 'sanitize_textarea_field',
            'sms-username' => 'sanitize_text_field',
            'sms-password' => 'sanitize_text_field',
            'sms-from' => 'sanitize_text_field',
            'sms-pattern-code' => 'sanitize_text_field',
            'sms-pattern' => 'sanitize_textarea_field',
            'recipients-phone' => 'sanitize_textarea_field',
            'sms-text' => 'sanitize_textarea_field',
            'labels' => 'sanitize_text_field',
            'date-format' => 'sanitize_text_field',
            'print-count-invoice' => 'sanitize_text_field',
            'print-count-packing-slip' => 'sanitize_text_field',
            'print-count-post-label' => 'sanitize_text_field',
            'print-count-order-label' => 'sanitize_text_field',
            'print-count-shop-mini-label' => 'sanitize_text_field',
            'print-count-customer-mini-label' => 'sanitize_text_field',
        ];
    }
}