<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Order_Actions {

    private $options;

    public function __construct() {
        $this->options = new WIP_Options_Manager();

        add_filter('woocommerce_admin_order_actions', [$this, 'order_actions'], 10, 2);
        if ($this->options->get_option('account-btn')) {
            add_filter('woocommerce_my_account_my_orders_actions', [$this, 'my_orders_actions'], 10, 2);
        }
        if ($this->options->get_option('thankyou-btn')) {
            add_filter('woocommerce_thankyou', [$this, 'thankyou'], 10, 1);
        }
        add_filter('bulk_actions-edit-shop_order', [$this, 'bulk_actions']);
    }

    public function order_actions($actions, $order) {
        $order_id = $order->get_id();

        $invoice_url = [
            'action' => 'wip-print',
            'type' => 'invoice',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'invoice'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $packing_url = [
            'action' => 'wip-print',
            'type' => 'packing-slip',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'packing-slip'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $label_url = [
            'action' => 'wip-print',
            'type' => 'post-label',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'post-label'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $order_label_url = [
            'action' => 'wip-print',
            'type' => 'order-label',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'shop-mini-label'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $mini_shop_label_url = [
            'action' => 'wip-print',
            'type' => 'shop-mini-label',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'shop-mini-label'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $mini_customer_label_url = [
            'action' => 'wip-print',
            'type' => 'customer-mini-label',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'customer-mini-label'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];
        $product_label_url = [
            'action' => 'wip-print',
            'type' => 'product-label',
            'order-id' => WIP_Helper::generate_order_id($order_id, 'product-label'),
            'wip-nonce' => wp_create_nonce('wip_nonce'),
        ];

        if ($this->options->get_option('vendor-address') && WIP_Helper::is_dokan_dashboard()) {
            $invoice_url['is-vendor'] = 1;
            $packing_url['is-vendor'] = 1;
            $label_url['is-vendor'] = 1;
            $mini_shop_label_url['is-vendor'] = 1;
            $mini_customer_label_url['is-vendor'] = 1;
        }

        if ($this->options->get_option('invoice-btn')) {
            $actions['wip-invoice'] = [
                'url' => esc_url(add_query_arg($invoice_url, WIP_Helper::base_url())),
                'name' => __('Invoice page', 'wip'),
                'action' => "wip-invoice",
            ];
        }
        if ($this->options->get_option('packing-slip-btn')) {
            $actions['wip-packing-slip'] = [
                'url' => esc_url(add_query_arg($packing_url, WIP_Helper::base_url())),
                'name' => __('Packing list page', 'wip'),
                'action' => "wip-packing-slip",
            ];
        }
        if ($this->options->get_option('post-label-btn')) {
            $actions['wip-post-label'] = [
                'url' => esc_url(add_query_arg($label_url, WIP_Helper::base_url())),
                'name' => __('Post label', 'wip'),
                'action' => "wip-post-label",
            ];
        }
        if ($this->options->get_option('order-label-btn')) {
            $actions['wip-order-label'] = [
                'url' => esc_url(add_query_arg($order_label_url, WIP_Helper::base_url())),
                'name' => __('Order label', 'wip'),
                'action' => "wip-order-label",
            ];
        }
        if ($this->options->get_option('shop-mini-label-btn')) {
            $actions['wip-shop-mini-label'] = [
                'url' => esc_url(add_query_arg($mini_shop_label_url, WIP_Helper::base_url())),
                'name' => __('Shop mini label', 'wip'),
                'action' => "wip-shop-mini-label",
            ];
        }
        if ($this->options->get_option('shop-mini-label-btn')) {
            $actions['wip-customer-mini-label'] = [
                'url' => esc_url(add_query_arg($mini_customer_label_url, WIP_Helper::base_url())),
                'name' => __('Customer mini label', 'wip'),
                'action' => "wip-customer-mini-label",
            ];
        }
        if ($this->options->get_option('product-label-btn')) {
            $actions['wip-product-label'] = [
                'url' => esc_url(add_query_arg($product_label_url, WIP_Helper::base_url())),
                'name' => __('Product label', 'wip'),
                'action' => "wip-product-label",
            ];
        }

        return $actions;
    }

    public function my_orders_actions($actions, $order) {
        $order_id = $order->get_id();
        $user_id = get_current_user_id();
        if (!(new WIP_Invoice_Access($order_id, $user_id))->check_permission()) {
            return $actions;
        }

        $actions['wip-invoice'] = array(
            'url' => esc_url(
                add_query_arg(
                    [
                        'action' => 'wip-print',
                        'type' => 'invoice',
                        'order-id' => $order_id,
                        'wip-nonce' => wp_create_nonce('wip_nonce'),
                    ],
                    WIP_Helper::base_url()
                )
            ),
            'name' => __('View invoice', 'wip'),
        );

        return $actions;
    }

    public function thankyou($order_id) {
        if (!is_user_logged_in() || !WIP_Helper::check_receiving($order_id)) {
            return null;
        }

        $url = add_query_arg(
            [
                'action' => 'wip-print',
                'type' => 'invoice',
                'order-id' => $order_id,
                'wip-nonce' => wp_create_nonce('wip_nonce'),
            ],
            WIP_Helper::base_url()
        );
        echo '<p><a href="' . esc_url($url) . '" class="button wip-invoice" target="_blank">' . __('View invoice', 'wip') . '</a></p>';
    }

    public function bulk_actions($bulk_actions) {
        $bulk_actions['wip_bulk_print_invoice'] = __('Print invoice', 'wip');
        $bulk_actions['wip_bulk_print_packing-slip'] = __('Print packing slip', 'wip');
        $bulk_actions['wip_bulk_print_post-label'] = __('Print post label', 'wip');
        $bulk_actions['wip_bulk_print_order-label'] = __('Print order label', 'wip');
        $bulk_actions['wip_bulk_print_shop-mini-label'] = __('Print shop mini label', 'wip');
        $bulk_actions['wip_bulk_print_customer-mini-label'] = __('Print customer mini label', 'wip');
        $bulk_actions['wip_bulk_print_product-label'] = __('Print product label', 'wip');

        return $bulk_actions;
    }
}