<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Order_Data extends WIP_Data {

    protected $order_id;
    protected $order;
    protected $type;

    public function __construct($order_id, $type) {
        parent::__construct();
        $this->order_id = $order_id;
        $this->order = wc_get_order($order_id);
        $this->type = $type;
    }

    public function is_show($component) {
        return isset($this->components[$component][$this->type]);
    }

    public function get_order_id() {
        $order_num = $this->order->get_order_number();
        $prefix = $this->options->get_option('prefix');
        $suffix = $this->options->get_option('suffix');
        $start = $this->options->get_option('start-num');
        $start = $start ? $start : 0;
        if (is_numeric($order_num)) {
            $order_num = $start + $order_num;
        }

        return $prefix . $order_num . $suffix;
    }

    public function get_customer_note() {
        return $this->order->get_customer_note();
    }

    public function get_order_note() {
        $order_note = $this->options->get_option('order-note');
        $invoice_note = get_post_meta($this->order_id, '_wip_invoice_note', true);
        $packing_slip_note = get_post_meta($this->order_id, '_wip_packing_slip_note', true);

        if ($invoice_note && ($this->type == 'invoice' || $this->type == 'order')) {
            return $invoice_note;
        }
        if ($packing_slip_note && $this->type == 'packing-slip') {
            return $packing_slip_note;
        }

        return $order_note;
    }

    private function get_signature() {
        return $this->options->get_option('shop-signature');
    }

    private function get_watermark() {
        $watermark = $this->options->get_option('watermark');
        $watermark_pending = $this->options->get_option('watermark-pending');
        $watermark_processing = $this->options->get_option('watermark-processing');
        $watermark_on_hold = $this->options->get_option('watermark-on-hold');
        $watermark_completed = $this->options->get_option('watermark-completed');
        $watermark_cancelled = $this->options->get_option('watermark-cancelled');
        $watermark_refunded = $this->options->get_option('watermark-refunded');
        $watermark_failed = $this->options->get_option('watermark-failed');
        if ($this->order) {
            $status = $this->order->get_status();
            if ($status == 'pending' && $watermark_pending) {
                return $watermark_pending;
            }
            if ($status == 'processing' && $watermark_processing) {
                return $watermark_processing;
            }
            if ($status == 'on-hold' && $watermark_on_hold) {
                return $watermark_on_hold;
            }
            if ($status == 'completed' && $watermark_completed) {
                return $watermark_completed;
            }
            if ($status == 'cancelled' && $watermark_cancelled) {
                return $watermark_cancelled;
            }
            if ($status == 'refunded' && $watermark_refunded) {
                return $watermark_refunded;
            }
            if ($status == 'failed' && $watermark_failed) {
                return $watermark_failed;
            }
        }

        return $watermark;
    }

    public function get_customer_note_html() {
        $note = $this->get_customer_note();
        if ($note && $this->is_show('customer-note')) {
            return $this->get_html('customer-note', $note);
        }

        return null;
    }

    public function get_order_note_html() {
        $note = $this->get_order_note();
        if ($note && $this->is_show('order-note')) {
            return $this->get_html('order-note', $note);
        }

        return null;
    }

    public function get_shop_signature_html() {
        $signature = $this->get_signature();
        if ( /*$signature &&*/ $this->is_show('signature-shop')) {
            $img = $signature ? '<img src="' . wp_get_attachment_url($signature) . '">' : null;

            return '<div class="shop-signature"><span class="title">' . $this->labels->get_label('shop-signature') . '</span>' . $img . '</div>';
        }

        return null;
    }

    public function get_customer_signature_html() {
        if ($this->is_show('signature-customer')) {
            return '<div class="customer-signature"><span class="title">' . $this->labels->get_label('customer-signature') . '</span></div>';
        }

        return null;
    }

    public function get_deliver_date_html() {
        if ($this->is_show('deliver-time')) {
            return '<div class="deliver-date"><span class="title">' . $this->labels->get_label('deliver-date') . '</span></div>';
        }

        return null;
    }

    public function get_deliver_time_html() {
        if ($this->is_show('deliver-time')) {
            return '<div class="deliver-time"><span class="title">' . $this->labels->get_label('deliver-time') . '</span></div>';
        }

        return null;
    }

    public function get_watermark_html() {
        $watermark = $this->get_watermark();
        $opacity = $this->options->get_option('watermark-opacity');
        $opacity = $opacity ? $opacity : '0.5';
        if ($watermark) {
            return '<img class="watermark" src="' . wp_get_attachment_url($watermark) . '" style="opacity: ' . esc_attr($opacity) . '">';
        }

        return null;
    }
}