<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Pre_Products_Table extends WIP_Products_Table {

    use WIP_Product_Data;

    private $items;

    public function __construct($order_id, $type) {
        parent::__construct($order_id, $type);
        $this->items = WC()->cart->get_cart();
    }

    public function render_html() {
        if (!isset($this->components['products-table']['pre-invoice'])) {
            return null;
        }
        if (!is_array($this->items)) {
            return null;
        }

        $id_label = $this->labels->get_label('id');
        $barcode_label = $this->labels->get_label('barcode');
        $image_label = $this->labels->get_label('image');
        $product_label = $this->labels->get_label('product');
        $seller_label = $this->labels->get_label('seller');
        $weight_label = $this->labels->get_label('weight');
        $dimension_label = $this->labels->get_label('dimension');
        $cabinet_label = $this->labels->get_label('cabinet-code');
        $price_label = $this->labels->get_label('price');
        $discount_label = $this->labels->get_label('discount-amount');
        $quantity_label = $this->labels->get_label('quantity');
        $total_label = $this->labels->get_label('total-amount');
        $note_label = $this->labels->get_label('purchase-note');

        $row_ordering = $this->options->get_option('ordering-products-row');
        $row_ordering = $row_ordering ? $row_ordering : 100;
        $id_ordering = $this->options->get_option('ordering-products-id');
        $id_ordering = $id_ordering ? $id_ordering : 101;
        $barcode_ordering = $this->options->get_option('ordering-products-barcode');
        $barcode_ordering = $barcode_ordering ? $barcode_ordering : 102;
        $image_ordering = $this->options->get_option('ordering-products-image');
        $image_ordering = $image_ordering ? $image_ordering : 103;
        $product_ordering = $this->options->get_option('ordering-products-product');
        $product_ordering = $product_ordering ? $product_ordering : 104;
        $seller_ordering = $this->options->get_option('ordering-products-seller');
        $seller_ordering = $seller_ordering ? $seller_ordering : 105;
        $weight_ordering = $this->options->get_option('ordering-products-weight');
        $weight_ordering = $weight_ordering ? $weight_ordering : 106;
        $dimension_ordering = $this->options->get_option('ordering-products-dimension');
        $dimension_ordering = $dimension_ordering ? $dimension_ordering : 107;
        $cabinet_code_ordering = $this->options->get_option('ordering-products-cabinet-code');
        $cabinet_code_ordering = $cabinet_code_ordering ? $cabinet_code_ordering : 108;
        $price_ordering = $this->options->get_option('ordering-products-price');
        $price_ordering = $price_ordering ? $price_ordering : 109;
        $extra_column_ordering = $this->options->get_option('ordering-products-extra-column');
        $extra_column_ordering = $extra_column_ordering ? $extra_column_ordering : 110;
        $discount_ordering = $this->options->get_option('ordering-products-discount');
        $discount_ordering = $discount_ordering ? $discount_ordering : 111;
        $quantity_ordering = $this->options->get_option('ordering-products-quantity');
        $quantity_ordering = $quantity_ordering ? $quantity_ordering : 112;
        $total_ordering = $this->options->get_option('ordering-products-total');
        $total_ordering = $total_ordering ? $total_ordering : 113;
        $purchase_note_ordering = $this->options->get_option('ordering-products-purchase-note');
        $purchase_note_ordering = $purchase_note_ordering ? $purchase_note_ordering : 114;

        $product_meta = $this->options->get_option('product-meta');
        $col_span = 0;
        $total_discount = 0;
        $total_quantity = 0;
        $total_amount = 0;

        $table = '<table class="products-table table-responsive table-bordered">';
        $table .= '<thead>';
        $table .= '<tr>';
        $head_array = [];
        if ($this->is_show('products-row')) {
            $head_array[$row_ordering] = '<th class="row">#</th>';
            $col_span++;
        }
        if ($this->is_show('products-id')) {
            $head_array[$id_ordering] = '<th class="id">' . esc_html($id_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-barcode')) {
            $head_array[$barcode_ordering] = '<th class="barcode">' . esc_html($barcode_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-image')) {
            $head_array[$image_ordering] = '<th class="image">' . esc_html($image_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-product')) {
            $head_array[$product_ordering] = '<th class="product">' . esc_html($product_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-seller')) {
            $head_array[$seller_ordering] = '<th class="seller">' . esc_html($seller_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-weight')) {
            $head_array[$weight_ordering] = '<th class="weight">' . esc_html($weight_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-dimension')) {
            $head_array[$dimension_ordering] = '<th class="dimension">' . esc_html($dimension_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-cabinet-code')) {
            $head_array[$cabinet_code_ordering] = '<th class="cabinet-code">' . esc_html($cabinet_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-price')) {
            $head_array[$price_ordering] = '<th class="price">' . esc_html($price_label) . '</th>';
            $col_span++;
        }
        if ($this->is_show('products-extra-column')) {
            if ($product_meta && is_array($product_meta)) {
                foreach ($product_meta as $value) {
                    list($label, $key) = explode('@', $value);
                    $head_array[$extra_column_ordering][] = '<th class="meta">' . esc_html($label) . '</th>';
                    $col_span++;
                }
            }
        }
        if ($this->is_show('products-discount')) {
            $head_array[$discount_ordering] = '<th class="discount-amount">' . esc_html($discount_label) . '</th>';
        }
        if ($this->is_show('products-quantity')) {
            $head_array[$quantity_ordering] = '<th class="quantity">' . esc_html($quantity_label) . '</th>';
        }
        if ($this->is_show('products-total')) {
            $head_array[$total_ordering] = '<th class="total-amount">' . esc_html($total_label) . '</th>';
        }
        if ($this->is_show('products-purchase-note')) {
            $head_array[$purchase_note_ordering] = '<th class="note">' . esc_html($note_label) . '</th>';
        }

        ksort($head_array);
        if (count($head_array)) {
            foreach ($head_array as $key => $head_item) {
                if (is_array($head_item) && count($head_item)) {
                    foreach ($head_item as $h_item) {
                        $table .= $h_item;
                    }
                } else {
                    $table .= $head_item;
                }
            }
        }

        $table .= '</tr>';
        $table .= '</thead>';
        $table .= '<tbody>';

        $i = 0;
        $body_array = [];
        foreach ($this->items as $item => $values) {
            $product_id = $values['data']->get_id();
            $product = wc_get_product($values['data']->get_id());
            $name = $product->get_name();
            $quantity = $values['quantity'];
            $price = $this->get_price($product_id);
            $item_data = $this->options->get_option('show-pre-invoice-variation') ? wc_get_formatted_cart_item_data($values) : '';

            $table .= '<tr class="' . ($i % 2 == 0 ? 'odd' : 'even') . '">';
            if ($this->is_show('products-row')) {
                $body_array[$row_ordering] = '<td class="row">' . ($i + 1) . '</td>';
            }
            if ($this->is_show('products-id')) {
                $body_array[$id_ordering] = '<td class="id"><span class="td-title">' . esc_html($id_label) . '</span>' . $this->get_id($product_id) . '</td>';
            }
            if ($this->is_show('products-barcode')) {
                $body_array[$barcode_ordering] = '<td class="barcode">' . WIP_Helper::get_barcode($this->get_id($product_id)) . '</td>';
            }
            if ($this->is_show('products-image')) {
                $body_array[$image_ordering] = '<td class="image">' . $this->get_image($product_id) . '</td>';
            }
            if ($this->is_show('products-product')) {
                $body_array[$product_ordering] = '<td class="product"><span class="td-title">' . esc_html($product_label) . '</span><a href="' . get_permalink($product_id) . '" target="_blank">' . $this->get_title($name, $product, $item) . '</a>' . $item_data . '</td>';
            }
            if ($this->is_show('products-seller')) {
                $body_array[$seller_ordering] = '<td class="seller"><span class="td-title">' . esc_html($seller_label) . '</span>' . $this->get_seller($product_id) . '</td>';
            }
            if ($this->is_show('products-weight')) {
                $body_array[$weight_ordering] = '<td class="weight"><span class="td-title">' . esc_html($weight_label) . '</span><bdi dir="ltr">' . $this->get_weight($product, $quantity) . '</bdi></td>';
            }
            if ($this->is_show('products-dimension')) {
                $body_array[$dimension_ordering] = '<td class="dimension"><span class="td-title">' . esc_html($dimension_label) . '</span><bdi dir="ltr">' . $this->get_dimensions($product) . '</bdi></td>';
            }
            if ($this->is_show('products-cabinet-code')) {
                $body_array[$cabinet_code_ordering] = '<td class="cabinet-code"><span class="td-title">' . esc_html($cabinet_label) . '</span>' . $this->get_cabinet_code($product_id) . '</td>';
            }
            if ($this->is_show('products-price')) {
                $body_array[$price_ordering] = '<td class="price"><span class="td-title">' . esc_html($price_label) . '</span>' . $this->get_price_html($product) . '</td>';
            }
            if ($this->is_show('products-extra-column')) {
                if ($product_meta && is_array($product_meta)) {
                    foreach ($product_meta as $value) {
                        list($label, $key) = explode('@', $value);
                        $meta_value = get_post_meta($product_id, $key, true);
                        $body_array[$extra_column_ordering][] = '<td class="meta"><span class="td-title">' . esc_html(esc_attr($label)) . '</span>' . esc_html($meta_value) . '</td>';
                    }
                }
            }
            if ($this->is_show('products-discount')) {
                $discount = $this->get_discount($product, $quantity);
                $total_discount += $discount;
                $body_array[$discount_ordering] = '<td class="discount-amount"><span class="td-title">' . esc_html($discount_label) . '</span>' . wc_price($discount) . '</td>';
            }
            if ($this->is_show('products-quantity')) {
                $total_quantity += $quantity;
                $body_array[$quantity_ordering] = '<td class="quantity"><span class="td-title">' . esc_html($quantity_label) . '</span>' . $quantity . '</td>';
            }
            if ($this->is_show('products-total')) {
                $total = $price * $quantity;
                $total_amount += $total;
                $body_array[$total_ordering] = '<td class="total-amount"><span class="td-title">' . esc_html($total_label) . '</span>' . wc_price($total) . '</td>';
            }
            if ($this->is_show('products-purchase-note')) {
                $body_array[$purchase_note_ordering] = '<td class="note"><span class="td-title">' . esc_html($note_label) . '</span>' . $this->get_purchase_note($product) . '</td>';
            }

            ksort($body_array);
            if (count($body_array)) {
                foreach ($body_array as $key => $body_item) {
                    if (is_array($body_item) && count($body_item)) {
                        foreach ($body_item as $b_item) {
                            $table .= $b_item;
                        }
                    } else {
                        $table .= $body_item;
                    }
                }
            }

            $table .= '</tr>';

            $i++;
        }

        $table .= '</tbody>';
        $table .= $this->get_footer($col_span, $total_discount, $total_quantity, $total_amount);
        $table .= '</table>';

        $table .= $this->get_total_weight();

        return $table;
    }

    private function get_price($product_id) {
        $product = wc_get_product($product_id);

        return intval($product->get_price());

        return intval(get_post_meta($product_id, '_price', true));
    }

    private function get_price_html($product) {
        $product_id = $product->get_id();
        if (!$this->options->get_option('regular-price')) {
            return wc_price($this->get_price($product_id));
        }

        return $product->is_on_sale() ? '<del>' . wc_price($product->get_regular_price()) . '</del><ins>' . wc_price($product->get_sale_price()) . '</ins>' : wc_price($product->get_regular_price());

    }

    private function get_discount($product, $quantity) {
        if (!$product->is_on_sale()) {
            return 0;
        }
        $regular_price = (float)$product->get_regular_price();
        $sale_price = (float)$product->get_price();

        return ($regular_price - $sale_price) * $quantity;
    }

    private function get_footer($col_span, $discount, $quantity, $total) {
        if (!isset($this->components['products-footer'][$this->type])) {
            return null;
        }

        $html = '<tfoot>';
        $html .= '<tr>';
        if ($col_span) {
            $html .= '<th class="total" colspan="' . $col_span . '">' . $this->labels->get_label('total') . '</th>';
        }
        if ($this->is_show('products-discount')) {
            $html .= '<td class="discount-amount">' . wc_price($discount) . '</td>';
        }
        if ($this->is_show('products-quantity')) {
            $html .= '<td class="quantity">' . $quantity . '</td>';
        }
        if ($this->is_show('products-total')) {
            $cs = isset($this->components['products-purchase-note'][$this->type]) ? 'colspan="2"' : null;
            $html .= '<td class="total-amount" ' . $cs . '>' . wc_price($total) . '</td>';
        }
        $html .= '</tr>';
        $html .= '</tfoot>';

        return $html;
    }

    private function get_total_weight() {
        $html = '';
        if ($this->is_show('total-weight')) {
            $html = '<div class="weight-wrapper">';
            $html .= '<div class="total-weight">';
            $html .= '<span class="title">' . $this->labels->get_label('total-weight') . '</span>';
            $html .= '<span class="content"><bdi dir="ltr">' . wc_format_weight(WC()->cart->get_cart_contents_weight()) . '</bdi></span>';
            $html .= '</div>';
            $html .= '</div>';
        }

        return $html;
    }
}