<?php
defined( 'ABSPATH' ) || exit( __( 'No Access!', 'wip' ) );

class WIP_Send_SMS {

	private $order_id;
	private $options;

	public function __construct( $order_id ) {
		$this->order_id = $order_id;
		$this->options = new WIP_Options_Manager();
	}

	public function get_message() {
		$text = $this->options->get_option( 'sms-text' );
		$customer = new WIP_Customer_Info( $this->order_id, null );
		$order = wc_get_order( $this->order_id );

		$search = [
			'{{order-id}}',
			'{{order-status}}',
			'{{products}}',
			'{{address}}',
			'{{full-name}}',
			'{{postcode}}',
			'{{phone}}',
			'{{email}}',
			'{{order-date}}',
			'{{payment-method}}',
			'{{transaction-id}}',
			'{{national-id}}',
			'{{shipping-method}}',
			'{{total-amount}}',
			'{{discount-amount}}',
			'{{tax-amount}}',
			'{{shipping-amount}}',
			'{{final-amount}}',
			'{{refunded-amount}}',
			'{{total-items}}',
		];
		$replace = [
			( new WIP_Order_Data( $this->order_id, 'sms' ) )->get_order_id(),
			wc_get_order_status_name( $order->get_status() ),
			html_entity_decode( strip_tags( ( new WIP_Products_Table( $this->order_id, 'sms' ) )->get_list( false ) ), ENT_QUOTES, 'UTF-8' ),
			$customer->get_address(),
			$customer->get_full_name(),
			$customer->get_postcode(),
			$customer->get_phone(),
			$customer->get_email(),
			( new WIP_Customer_Info( $this->order_id, 'sms' ) )->get_order_date(),
			$customer->get_payment_method(),
			$customer->get_transaction_id(),
			$customer->get_national_id(),
			$customer->get_shipping_method(),
			html_entity_decode( strip_tags( wc_price( $order->get_subtotal() ) ), ENT_QUOTES, 'UTF-8' ),
			html_entity_decode( strip_tags( wc_price( $order->get_total_discount() ) ), ENT_QUOTES, 'UTF-8' ),
			html_entity_decode( strip_tags( wc_price( $order->get_total_tax() ) ), ENT_QUOTES, 'UTF-8' ),
			html_entity_decode( strip_tags( wc_price( $order->get_shipping_total() ) ), ENT_QUOTES, 'UTF-8' ),
			html_entity_decode( strip_tags( wc_price( $order->get_total() ) ), ENT_QUOTES, 'UTF-8' ),
			html_entity_decode( strip_tags( wc_price( $order->get_total_refunded() ) ), ENT_QUOTES, 'UTF-8' ),
			$order->get_item_count(),
		];

		return str_replace( $search, $replace, $text );
	}

	public function send( $to ) {
		$service = $this->options->get_option( 'sms-service' );
		if ( ! $service ) {
			return null;
		}
		$class = 'WIP_' . ucfirst( $service );
		( new $class( $this->order_id, $to, $this->get_message() ) )->send();
	}
}