<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_Total_Table extends WIP_Order_Data {

    public function render_html() {
        if (!isset($this->components['total-table'][$this->type])) {
            return null;
        }

        $total = $this->order->get_order_item_totals();
        $refunded = $this->order->get_total_refunded();
        $coupon = $this->order->get_coupon_codes();
        $fee = $this->order->get_total_fees();

        $table = '<table class="total-table table-responsive table-bordered table-fixed">';
        $table .= '<tbody>';
        if (isset($total['cart_subtotal']['value']) && $this->is_show('total-total')) {
            $table .= '<tr>';
            $table .= '<th class="total">' . esc_html($this->labels->get_label('total-amount')) . '</th>';
            $table .= '<td class="total">' . $total['cart_subtotal']['value'] . '</td>';
            $table .= '</tr>';
        }
        if (isset($total['discount']['value']) && $this->is_show('total-discount')) {
            $table .= '<tr>';
            $table .= '<th class="discount">' . esc_html($this->labels->get_label('discount-amount')) . '</th>';
            $table .= '<td class="discount">';
            $table .= $total['discount']['value'];
            $table .= count($coupon) ? '<div class="coupon-codes">' . __('Coupon codes:', 'wip') . implode(',', $coupon) . '</div>' : null;
            $table .= '</td>';
            $table .= '</tr>';
        }
        if (isset($this->components['total-tax'][$this->type])) {
            $table .= $this->get_tax();
        }
        if (isset($total['shipping']['value']) && $this->is_show('total-shipping')) {
            $table .= '<tr>';
            $table .= '<th class="shipping">' . esc_html($this->labels->get_label('shipping-amount')) . '</th>';
            if ($this->order->get_shipping_total() == '0') {
                $table .= '<td class="shipping">' . wc_price($this->order->get_shipping_total()) . '</td>';
            } else {
                $table .= '<td class="shipping">' . $total['shipping']['value'] . '</td>';
            }
            $table .= '</tr>';
        }
        if ($fee && $this->is_show('total-fee')) {
            foreach ($this->order->get_items('fee') as $item_id => $item) {
                $table .= '<tr>';
                $table .= '<th class="shipping">' . $item->get_name() . '</th>';
                $table .= '<td class="shipping">' . wc_price($item->get_total()) . '</td>';
                $table .= '</tr>';
            }
        }
        if (isset($total['order_total']['value']) && $this->is_show('total-final')) {
            $table .= '<tr>';
            $table .= '<th class="final">' . esc_html($this->labels->get_label('final-amount')) . '</th>';
            $table .= '<td class="final">' . $total['order_total']['value'] . '</td> ';
            $table .= '</tr>';
        }
        if ($refunded && $this->is_show('total-refunded')) {
            $table .= ' <tr>';
            $table .= ' <th class="final"> ' . esc_html($this->labels->get_label('refunded-amount')) . ' </th> ';
            $table .= '<td class="final"> ' . wc_price($refunded) . '</td> ';
            $table .= '</tr> ';
        }
        $table .= '</tr>';
        if ($this->options->get_option('to-word')) {
            $table .= '<tr><td class="to-word" colspan="2">' . WIP_Helper::to_word($this->order->get_total() - $refunded) . ' ' . get_woocommerce_currency_symbol() . '</td></tr>';
        }
        $table .= '</tbody>';
        $table .= '</table>';

        return $table;
    }

    private function get_tax() {
        $tax = $this->order->get_tax_totals();

        $html = '';
        if (is_array($tax) && count($tax)) {
            $amount = 0;
            foreach ($tax as $tax_key => $tax_value) {
                if (isset($tax_value->formatted_amount)) {
                    $html .= '<tr><th class="tax"> ' . $tax_key . '</th><td class="tax"> ' . $tax_value->formatted_amount . '</td></tr> ';
                }
                if (isset($tax_value->amount)) {
                    $amount += $tax_value->amount;
                }
            }
            if (count($tax) > 1) {
                $html .= '<tr><th class="tax"> ' . esc_html($this->labels->get_label('tax-amount')) . '</th><td class="tax" > ' . wc_price($amount) . '</td></tr> ';
            }
        }

        return $html;
    }
}