<?php
defined('ABSPATH') || exit(__('No Access!', 'wip'));

class WIP_View {

    protected $options;
    protected $action;
    protected $type;
    protected $is_email;

    public function __construct($is_email = false) {
        $this->options = new WIP_Options_Manager();
        $this->action = $_GET['action'] ?? null;
        $this->type = $_GET['type'] ?? null;
        $this->is_email = $is_email;
    }

    public function get_type() {
        return $this->type;
    }

    public function set_type($type) {
        $this->type = $type;

        return $this;
    }

    public function get_is_email() {
        return $this->is_email;
    }

    public function set_is_email($is_email) {
        $this->is_email = $is_email;

        return $this;
    }

    private function get_view_type() {
        $type = $this->type;
        if ($type == 'packing-slip') {
            $type = 'invoice';
        }
        if ($type == 'order-label' || $type == 'shop-mini-label' || $type == 'customer-mini-label' || $type == 'product-label') {
            $type = 'post-label';
        }

        return $type;
    }

    private function get_template_type() {
        $type = $this->get_type();

        return $type == 'packing-slip' ? 'invoice' : $type;
    }

    private function get_template() {
        $template = $this->options->get_option($this->get_template_type() . '-template');

        return $template && !is_page() ? $template : 'template-1';
    }

    protected function get_template_file() {
        $file = trailingslashit(WIP_TPL_PATH . $this->get_template_type()) . $this->get_template() . '.php';

        if (file_exists($file) && is_readable($file)) {
            return $file;
        }

        return null;
    }

    public function get_template_html() {
        $template = $this->get_template_file();
        if ($template) {
            ob_start();
            include($template);
            $html = ob_get_clean();

            return $html;
        }

        return null;
    }

    private function get_style_file() {
        $template = $this->get_template();
        $number = substr($template, 9);

        $file = WIP_CSS_PATH . $this->get_template_type() . '-' . $number . '.css';
        if (file_exists($file) && is_readable($file)) {
            return $file;
        }

        return null;
    }

    public function get_font_family() {
        return $this->options->get_option($this->get_view_type() . '-font-family');
    }

    public function get_styles() {
        $type = $this->get_view_type();
        $color = $this->options->get_option($type . '-color');
        $font_family = $this->get_font_family();
        $font_size = $this->options->get_option($type . '-font-size');
        $margin = $this->options->get_option($type . '-margin');
        $custom_css = $this->options->get_option('custom-css');
        $border = $this->options->get_option($type . '-border');
        $style_file = $this->get_style_file();

        ob_start();
        $template = $this->get_template();
        $break_point = '576px';

        echo $this->get_font($font_family);
        ?>
        <style type="text/css">
            <?php echo $style_file ? file_get_contents($style_file) : null; ?>
            <?php if ($color): ?>
            @media (max-width: <?php echo $break_point; ?>) {
                .table-bordered tbody tr:not(:last-child) td:last-child {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }

                .total-table tbody tr:not(:last-child) th {
                    border-bottom-color: <?php echo '#'.esc_html($color); ?> !important;
                }
            }

            <?php if ($this->get_type() == 'invoice' || $this->get_type() == 'packing-slip'): ?>
            .invoice .table-bordered {
                border-color: #<?php echo esc_html($color); ?>;
            }

            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .table-bordered th, .invoice .table-bordered td {
                    border-color: #<?php echo esc_html($color); ?>;
                }
            }

            @media (max-width: <?php echo $break_point; ?>) {
                .invoice .products-table tbody tr.even td {
                    background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?> !important;
                }
            }

            <?php if ($template == 'template-1'): ?>
            .invoice .template-1 .shop-info {
                border-color: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-1 .shop-info tfoot td {
                background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?>;
            }

            .invoice .template-1 .customer-info {
                border-color: #<?php echo esc_html($color); ?>;
                background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?>;
            }

            .invoice .template-1 th {
                background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?>;
            }

            .invoice .template-1 .customer-note,
            .invoice .template-1 .order-note {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            <?php endif; ?>
            <?php if ($template == 'template-2'): ?>
            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .template-2 .products-table th,
                .invoice .template-2 .products-table td {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }
            }

            .invoice .template-2 .shop-info {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-2 .invoice-title {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-2 .invoice-title:after {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
                border-top-color: transparent !important;
                border-bottom-color: transparent !important;
            }

            .invoice .template-2 .sender-customer-table td {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-2 .products-table th {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-2 .products-table th {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-2 .total-table .final {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-2 .total-table .final:after {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
                border-top-color: transparent !important;
                border-bottom-color: transparent !important;
            }

            .invoice .template-2 .customer-note,
            .invoice .template-2 .order-note {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            <?php endif; ?>
            <?php if ($template == 'template-3'): ?>
            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .template-3 .products-table th,
                .invoice .template-3 .products-table td {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }
            }

            .invoice .template-3 .shop-info {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-3 .sender-customer-table td {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-3 .products-table th,
            .invoice .template-3 .products-table td, {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-3 .customer-note,
            .invoice .template-3 .order-note {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            <?php endif; ?>
            <?php if ($template == 'template-4'): ?>
            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .template-4 .products-table th {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }

                .invoice .template-4 .products-table tbody > tr:last-child td {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }
            }

            .invoice .template-4 .shop-info {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-4 .invoice-title {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-4 .products-table td.row span {
                background: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-4 .total-table .final {
                background: #<?php echo esc_html($color); ?>;
            }

            <?php endif; ?>
            <?php if ($template == 'template-5'): ?>
            .invoice .template-5 .wrapper {
                border-color: #<?php echo esc_html($color); ?>;
            }

            .invoice .template-5 .sender-info > .title,
            .invoice .template-5 .customer-info > .title {
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-5 .sender-info > .content,
            .invoice .template-5 .customer-info > .content {
                background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?>;
                border-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-5 .products-table th {
                background: <?php echo esc_html(WIP_Helper::hex2rgba($color, 0.25)); ?>;
            }

            <?php endif; ?>
            <?php if ($template == 'template-6'): ?>
            .invoice .template-6 .star-line {
                color: <?php echo '#'.esc_html($color); ?>;
            }

            .invoice .template-6 .shop-info > tbody > tr > td:first-child {
                border-bottom-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-6 .products-table th {
                border-top-color: <?php echo '#'.esc_html($color); ?> !important;
                border-bottom-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-6 .profit-wrapper {
                border-top-color: <?php echo '#'.esc_html($color); ?> !important;
                border-bottom-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            .invoice .template-6 .total-table .final {
                border-top-color: <?php echo '#'.esc_html($color); ?> !important;
            }

            <?php endif; ?>
            <?php if ($template == 'template-7'): ?>
            .invoice .template-7 .shop-info {
                background: <?php echo '#'.esc_html($color); ?>;
            }

            .invoice .template-7 .shop-info .dollar {
                background: <?php echo '#'.esc_html($color); ?>;
            }

            .invoice .template-7 .customer-info .full-name {
                color: <?php echo '#'.esc_html($color); ?>;
            }

            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .template-7 .products-table th.row,
                .invoice .template-7 .products-table th.id,
                .invoice .template-7 .products-table th.image,
                .invoice .template-7 .products-table th.product {
                    background: <?php echo '#'.esc_html($color); ?>;
                }

                .invoice .template-7 .products-table th,
                .invoice .template-7 .products-table td {
                    border-bottom-color: <?php echo '#'.esc_html($color); ?>;
                }

                .invoice .template-7 .products-table th.product:after {
                    border-left-color: <?php echo '#'.esc_html($color); ?> !important;
                }

                .invoice.rtl .template-7 .products-table th.product:after {
                    border-right-color: <?php echo '#'.esc_html($color); ?> !important;
                }

                .invoice .template-7 .total-table td.final {
                    border-top-color: <?php echo '#'.esc_html($color); ?>;
                    background: <?php echo '#'.esc_html($color); ?>;
                }

                .invoice .template-7 .total-table th.final {
                    border-top-color: <?php echo '#'.esc_html($color); ?>;
                }
            }

            .invoice .template-7 .products-table th {
                color: <?php echo '#'.esc_html($color); ?>;
            }

            .invoice .template-7 .footer-table {
                border-top-color: <?php echo '#'.esc_html($color); ?>;
            }

            <?php endif; ?>
            <?php if ($template == 'template-8'): ?>
            .invoice .top-line {
                background: <?php echo '#'.esc_html($color); ?>;
            }

            <?php endif; ?>
            <?php if ($template == 'template-9'): ?>
            .invoice .template-9 .title-cell {
                background: <?php echo '#'.esc_html($color); ?>;
            }

            @media (min-width: <?php echo $break_point; ?>) {
                .invoice .template-9 .second-row .info-cell {
                    border-color: <?php echo '#'.esc_html($color); ?> !important;
                }

                .invoice .template-9 .second-row .products-cell {
                    border-bottom-color: <?php echo '#'.esc_html($color); ?>;
                }

                .invoice .table-bordered th,
                .invoice .table-bordered td {
                    border-color: #000;
                }
            }

            .invoice .bottom-line {
                background: <?php echo '#'.esc_html($color); ?>;
            }

            <?php endif; ?>
            <?php endif; ?>

            <?php endif; ?>
            <?php if ($font_family): ?>
            *, body, select, input {
                font-family: '<?php echo esc_html($font_family); ?>', Tahoma, Arial, sans-serif !important;
            }

            <?php endif; ?>
            <?php if ($font_size): ?>
            body {
                font-size: <?php echo esc_html($font_size); ?>px;
            }

            <?php endif; ?>
            <?php if ($margin): ?>
            .container {
                margin: <?php echo esc_html($margin); ?>px;
            }

            <?php endif; ?>
            <?php if ($border): ?>
            .container {
                border-color: <?php echo $color ? '#'.esc_html($color) : '#000'; ?>;
            }

            <?php endif; ?>
            <?php
			 if ($custom_css) {
				echo esc_html($custom_css);
			 }
			 ?>
        </style>
        <?php

        return ob_get_clean();
    }

    private function get_font($font_family) {
        ob_start();
        ?>
        <style type="text/css">
            <?php if ($font_family == 'IRANSans'): ?>
            @font-face {
                font-family: IRANSans;
                font-style: normal;
                font-weight: normal;
                src: url('<?php echo WIP_FONT_URL; ?>iransans/eot/IRANSansWeb.eot');
                src: url('<?php echo WIP_FONT_URL; ?>iransans/eot/IRANSansWeb.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>iransans/woff2/IRANSansWeb.woff2') format('woff2'),
                url('<?php echo WIP_FONT_URL; ?>iransans/woff/IRANSansWeb.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>iransans/ttf/IRANSansWeb.ttf') format('truetype');
            }

            @font-face {
                font-family: IRANSans;
                font-style: normal;
                font-weight: bold;
                src: url('<?php echo WIP_FONT_URL; ?>iransans/eot/IRANSansWeb_Bold.eot');
                src: url('<?php echo WIP_FONT_URL; ?>iransans/eot/IRANSansWeb_Bold.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>iransans/woff2/IRANSansWeb_Bold.woff2') format('woff2'),
                url('<?php echo WIP_FONT_URL; ?>iransans/woff/IRANSansWeb_Bold.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>iransans/ttf/IRANSansWeb_Bold.ttf') format('truetype');
            }

            <?php endif; ?>
            <?php if ($font_family == 'iranyekan'): ?>
            @font-face {
                font-family: iranyekan;
                font-style: normal;
                font-weight: normal;
                src: url('<?php echo WIP_FONT_URL; ?>iranyekan/eot/iranyekanwebregular.eot');
                src: url('<?php echo WIP_FONT_URL; ?>iranyekan/eot/iranyekanwebregular.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>iranyekan/woff/iranyekanwebregular.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>iranyekan/ttf/iranyekanwebregular.ttf') format('truetype');
            }
            @font-face {
                font-family: iranyekan;
                font-style: normal;
                font-weight: bold;
                src: url('<?php echo WIP_FONT_URL; ?>iranyekan/eot/iranyekanwebbold.eot');
                src: url('<?php echo WIP_FONT_URL; ?>iranyekan/eot/iranyekanwebbold.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>iranyekan/woff/iranyekanwebbold.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>iranyekan/ttf/iranyekanwebbold.ttf') format('truetype');
            }

            <?php endif; ?>
            <?php if ($font_family == 'Parastoo'): ?>
            @font-face {
                font-family: Parastoo;
                src: url('<?php echo WIP_FONT_URL; ?>parastoo/parastoo.eot');
                src: url('<?php echo WIP_FONT_URL; ?>parastoo/parastoo.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>parastoo/parastoo.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>parastoo/parastoo.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Sahel'): ?>
            @font-face {
                font-family: Sahel;
                src: url('<?php echo WIP_FONT_URL; ?>sahel/sahel.eot');
                src: url('<?php echo WIP_FONT_URL; ?>sahel/sahel.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>sahel/sahel.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>sahel/sahel.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Samim'): ?>
            @font-face {
                font-family: Samim;
                src: url('<?php echo WIP_FONT_URL; ?>samim/samim.eot');
                src: url('<?php echo WIP_FONT_URL; ?>samim/samim.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>samim/samim.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>samim/samim.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Shabnam'): ?>
            @font-face {
                font-family: Shabnam;
                src: url('<?php echo WIP_FONT_URL; ?>shabnam/shabnam.eot');
                src: url('<?php echo WIP_FONT_URL; ?>shabnam/shabnam.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>shabnam/shabnam.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>shabnam/shabnam.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Tanha'): ?>
            @font-face {
                font-family: Tanha;
                src: url('<?php echo WIP_FONT_URL; ?>tanha/tanha.eot');
                src: url('<?php echo WIP_FONT_URL; ?>tanha/tanha.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>tanha/tanha.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>tanha/tanha.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Yekan'): ?>
            @font-face {
                font-family: Yekan;
                src: url('<?php echo WIP_FONT_URL; ?>yekan/yekan.eot');
                src: url('<?php echo WIP_FONT_URL; ?>yekan/yekan.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>yekan/yekan.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>yekan/yekan.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'BNazanin'): ?>
            @font-face {
                font-family: 'BNazanin';
                src: url('<?php echo WIP_FONT_URL; ?>bnazanin/BNazanin.woff2') format('woff2'),
                url('<?php echo WIP_FONT_URL; ?>bnazanin/BNazanin.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>bnazanin/BNazanin.ttf') format('truetype');
            }

            <?php endif; ?>
            <?php if ($font_family == 'Koodakbold'): ?>
            @font-face {
                font-family: Koodakbold;
                src: url('<?php echo WIP_FONT_URL; ?>koodakbold/koodakbold.eot');
                src: url('<?php echo WIP_FONT_URL; ?>koodakbold/koodakbold.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>koodakbold/koodakbold.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>koodakbold/koodakbold.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Homa'): ?>
            @font-face {
                font-family: Homa;
                src: url('<?php echo WIP_FONT_URL; ?>homa/homa.eot');
                src: url('<?php echo WIP_FONT_URL; ?>homa/homa.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>homa/homa.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>homa/homa.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Mitra'): ?>
            @font-face {
                font-family: Mitra;
                src: url('<?php echo WIP_FONT_URL; ?>mitra/mitra.eot');
                src: url('<?php echo WIP_FONT_URL; ?>mitra/mitra.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>mitra/mitra.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>mitra/mitra.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Bardiya'): ?>
            @font-face {
                font-family: Bardiya;
                src: url('<?php echo WIP_FONT_URL; ?>bardiya/bardiya.eot');
                src: url('<?php echo WIP_FONT_URL; ?>bardiya/bardiya.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>bardiya/bardiya.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>bardiya/bardiya.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Ferdosi'): ?>
            @font-face {
                font-family: Ferdosi;
                src: url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.eot');
                src: url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Traffic'): ?>
            @font-face {
                font-family: Traffic;
                src: url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.eot');
                src: url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>ferdosi/ferdosi.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Yas'): ?>
            @font-face {
                font-family: Yas;
                src: url('<?php echo WIP_FONT_URL; ?>yas/yas.eot');
                src: url('<?php echo WIP_FONT_URL; ?>yas/yas.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>yas/yas.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>yas/yas.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Morvarid'): ?>
            @font-face {
                font-family: Morvarid;
                src: url('<?php echo WIP_FONT_URL; ?>morvarid/morvarid.eot');
                src: url('<?php echo WIP_FONT_URL; ?>morvarid/morvarid.eot?#iefix') format('embedded-opentype'),
                url('<?php echo WIP_FONT_URL; ?>morvarid/morvarid.woff') format('woff'),
                url('<?php echo WIP_FONT_URL; ?>morvarid/morvarid.ttf') format('truetype');
                font-weight: normal;
            }

            <?php endif; ?>
            <?php if ($font_family == 'Ubuntu'): ?>
            @import url('https://fonts.googleapis.com/css?family=Ubuntu&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Libre Franklin'): ?>
            @import url('https://fonts.googleapis.com/css?family=Libre+Franklin&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Questrial'): ?>
            @import url('https://fonts.googleapis.com/css?family=Questrial&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Comfortaa'): ?>
            @import url('https://fonts.googleapis.com/css?family=Comfortaa&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Courgette'): ?>
            @import url('https://fonts.googleapis.com/css?family=Courgette&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Lalezar'): ?>
            @import url('https://fonts.googleapis.com/css?family=Lalezar&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Markazi Text'): ?>
            @import url('https://fonts.googleapis.com/css?family=Markazi+Text&display=swap');

            <?php endif; ?>
            <?php if ($font_family == 'Almarai'): ?>
            @import url('https://fonts.googleapis.com/css?family=Almarai&display=swap');

            <?php endif; ?>
        </style>
        <?php
        return ob_get_clean();
    }

    public function body_class() {
        $class = $this->get_type();
        $class = $class == 'packing-slip' ? $class . ' invoice' : $class;
        $class = $this->options->get_option('condensed') ? $class . ' condensed' : $class;
        $class = $this->get_is_email() ? $class . ' is-email' : $class;
        $class = is_rtl() ? $class . ' rtl' : $class;

        return $class;
    }
}